@@ -1,7 +1,7 @@
 """
 Type annotations for codestar-notifications service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/literals/)
 
 Usage::
 
@@ -166,6 +166,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -267,6 +268,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
